@@ -788,8 +788,8 @@ void object_dump (jint data_len, char *data) {
 	    break;
 	case JVMPI_CHAR: {
 	    down_link* dl;
-	    char* txt = calloc (u4 + 1, sizeof(unsigned short));
-	    char* otxt = txt;
+	    unsigned char* txt = calloc (u4 + 1, sizeof(unsigned short));
+	    unsigned char* otxt = txt;
 	    for (i = 0; i < u4; i++) {
 		unsigned short u2 = get_u2 (&p);
 		/* this seems to be utf-16/ucs-2, but Im not sure... */
