@@ -14,6 +14,11 @@
 #include <jmp-config.h>
 #include <inttypes.h>
 
+#ifndef        PRId32
+/* Some systems still don't have the "print formatting" stuff in inttypes.h */
+#define        PRId32 "d"
+#endif
+
 enum {
     INFO,
     OO_PARENT,
