@@ -10,7 +10,9 @@ enum {
     MCALLS_COLUMN,
     MSUBS_COLUN,
     MTOTAL_COLUMN,
+    MTOTAL_CALL_COLUMN,
     MOBJECTS_COLUMN,
+    MOBJSCALL_COLUMN,
     MBYTES_COLUMN,
     MMETHOD_COLUMN,   /* pointer to the method, please keep next to last */
     MN_COLUMNS
