@@ -6,6 +6,7 @@
 #include <ui.h>
 #include <comparators.h>
 #include <dumper.h>
+#include <iconv.h>
 
 /** This file implements the ui interface. 
  *  The ui provided by this file is: none, dumping to file works.
@@ -250,6 +251,22 @@ void show_deadlock (visited_threads* vt) {
     }
 }
 
+char* jmp_utf16_to_utf8 (unsigned char* text, size_t count, 
+			 long* items_written, int* err) {
+    iconv_t cd; 
+    size_t non_rev_count;
+    size_t in_bytes_left;
+    size_t out_bytes_left;
+    char* out_buf;
+    char* in_buf = (char*)text;
+    cd = iconv_open("utf8", "utf16");
+    out_buf = malloc (4 * count);
+    non_rev_count = 
+	iconv (cd, &in_buf, &in_bytes_left, &out_buf, &out_bytes_left);
+    iconv_close (cd);
+    return out_buf;
+}
+
 /* Emacs Local Variables: */
 /* Emacs mode:C */
 /* Emacs c-indentation-style:"gnu" */
