@@ -671,6 +671,9 @@ wret create_object_dump_window () {
     gtk_widget_set_usize (obj_dump, 800, 200);
     ret.window = obj_dump;
     ret.clist = clist1;
+    ret.data = 0; 
+    ret.level = 0;
+    ret.row = 0;
     return ret;
 }
 
