@@ -8,7 +8,7 @@
 #include <jmp.h>
 #include <errno.h>
 #include <heap_dump.h>
-#include <gtk/gtk.h> /* TODO: remove... */
+#include <ui.h>
 
 static int string_file_counter = -1;
 static char filename[128];
@@ -28,18 +28,6 @@ int write_string (FILE* f, char* text, int count, int used) {
     return fprintf (f, "'%d'\t'%d'\t'%s'\n", used, count, text);    
 }
 
-/* TODO: change to non-glib-version. */
-char* utf16_to_utf8 (char* text, size_t count, long* items_written, int* err) {
-    GError* gerr = NULL;
-    glong iw;
-    glong ir;
-    char* ret;
-    
-    ret = g_utf16_to_utf8 ((gunichar2*)text, count, &ir, &iw, &gerr);
-    *items_written = iw;
-    return ret;
-}
-
 void dump_string (obj* o, FILE* f) {
     down_link* dl;
     get_instance_info (o);
@@ -51,7 +39,7 @@ void dump_string (obj* o, FILE* f) {
 
 	switch (dl->type) {
 	case JVMPI_GC_PRIM_ARRAY_DUMP:
-	    converted_text = utf16_to_utf8 (dl->value.txt, dl->pos, &items_written, &err); 
+	    converted_text = jmp_utf16_to_utf8 (dl->value.txt, dl->pos, &items_written, &err); 
 	    if (err != 0) {
 		fprintf (stderr, "Unable to convert text: %s\n", strerror (err));	
 		break;
@@ -71,4 +59,5 @@ void dump_strings () {
     FILE* f;
     f = get_string_dump_file ();
     for_each_string ((string_callback)dump_string, f);
+    fclose (f);
 }
