@@ -471,6 +471,17 @@ void show_deadlock (visited_threads* vt) {
    gtk_widget_show_all (dialog);
 }
 
+char* jmp_utf16_to_utf8 (unsigned char* text, size_t count, long* items_written, int* err) {
+    GError* gerr = NULL;
+    glong iw;
+    glong ir;
+    char* ret;
+    
+    ret = g_utf16_to_utf8 ((gunichar2*)text, count, &ir, &iw, &gerr);
+    *items_written = iw;
+    return ret;
+}
+
 /* Emacs Local Variables: */
 /* Emacs mode:C */
 /* Emacs c-indentation-style:"gnu" */
